==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/de_DE.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "There was a problem reading files from this album" : "Es gab ein Problem Dateien aus diesem Album zu lesen",
    "Aborting preview. Could not find the file" : "Die Vorschau wird abgebrochen. Die Datei konnte nicht gefunden werden",
    "Could not move \"{file}\", target exists" : "Konnte \"{file}\" nicht verschieben, Ziel existiert bereits",
    "Could not move \"{file}\"" : "Konnte \"{file}\" nicht verschieben ",
    "No compatible server found at {remote}" : "Keinen kompatiblen Server unter {remote} gefunden",
    "Invalid server url" : "Ungültige Server-URL",
    "Could not load the description" : "Die Beschreibung konnte nicht geladen werden",
    "Could not load the description: " : "Die Beschreibung konnte nicht geladen werden:",
    "Copyright" : "Urheberrecht",
    "Could not load the copyright notice: " : "Der Urheberrechtshinweis konnte nicht geladen werden:",
    "Copyright notice" : "Urheberrechtshinweis",
    "Link to copyright document" : "Link zum Urheberrechts-Dokument",
    "This application may not work properly on your browser." : "Diese Anwendung könnte mit Ihrem Browser nicht einwandfrei funktionieren",
    "For an improved experience, please install one of the following alternatives" : "Für eine bessere Erfahrung installieren Sie bitte eine der folgenden Alternativen",
    "Your browser is not supported!" : "Ihr Browser wird nicht unterstützt!",
    "please install one of the following alternatives" : "Bitte eine der folgenden Alternativen installieren",
    "Album cannot be shown" : "Album kann nicht angezeigt werden.",
    "No media files found" : "Keine Mediendateien gefunden.",
    "Upload pictures in the Files app to display them here" : "Laden Sie Bilder in der Dateien-App hoch, damit diese hier angezeigt werden. ",
    "Upload new files via drag and drop or by using the [+] button above" : "Lade neue Dateien via Drag and Drop oder mit der [+]-Schaltfläche hoch.",
    "Configuration error" : "Konfigurationsfehler",
    "New" : "Neu",
    "Hide Album" : "Album ausblenden",
    "Could not hide album" : "Album konnte nicht ausgeblendet werden",
    "Error loading slideshow template" : "Fehler beim Laden der Slideshow-Vorlage",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fehler!</strong> Konnte keine Vorschau dieser Datei erzeugen.<br> Bitte wechseln Sie zum nächsten Bild, während im Hintergrund das Bild aus der Diashow entfernt wird.",
    "Next" : "Weiter",
    "Play" : "Abspielen",
    "Pause" : "Anhalten",
    "Previous" : "Zurück",
    "Close" : "Schließen",
    "Download" : "Herunterladen",
    "Toggle background" : "Hintergrund umschalten",
    "Delete" : "Löschen",
    "Share" : "Teilen",
    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}“ ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"{name}\" is not an allowed filetype" : "\"{name}“ ist kein erlaubter Dateityp ",
    "Upload" : "Hochladen",
    "Error" : "Fehler",
    "Error while sharing" : "Fehler beim Teilen",
    "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
    "Error while changing permissions" : "Fehler beim Ändern der Rechte",
    "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Ihnen und der Gruppe {group} geteilt.",
    "Shared with you by {owner}" : "{owner} hat dies mit Ihnen geteilt",
    "Share with users or groups …" : "Mit Benutzern oder Gruppen teilen…",
    "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder externen Benutzern teilen…",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Teile mit Menschen auf anderen Servern unter Verwendung ihrer Federated Cloud ID username@example.com/cloud",
    "Share link" : "Link teilen",
    "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
    "Link" : "Link",
    "Password protect" : "Passwortschutz",
    "Password" : "Passwort",
    "Choose a password for the public link" : "Passwort für den öffentlichen Link eingeben",
    "Allow editing" : "Bearbeitung erlauben",
    "Email link to person" : "Link per E-Mail versenden",
    "Send" : "Senden",
    "Set expiration date" : "Ein Ablaufdatum setzen",
    "Expiration" : "Ablaufdatum",
    "Expiration date" : "Ablaufdatum",
    "This list is maybe truncated - please refine your search term to see more results." : "Die Liste ist unter Umständen gekürzt - Bitte verfeinern Sie Ihre Suche um mehr Ergebnisse zu erhalten. ",
    "No users or groups found for {search}" : "Keine Benutzer oder Gruppen gefunden für {search}",
    "No users found for {search}" : "Keine Benutzer für {search} gefunden",
    "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuchen Sie es noch einmal",
    "Adding user..." : "Benutzer wird hinzugefügt…",
    "group" : "Gruppe",
    "remote" : "Externe Freigabe",
    "Resharing is not allowed" : "Weiterteilen ist nicht erlaubt",
    "Error while retrieving shares" : "Fehler beim Abrufen der Freigaben",
    "Unshare" : "Freigabe aufheben",
    "notify by email" : "Per E-Mail benachrichtigen",
    "can share" : "kann teilen",
    "can edit" : "kann bearbeiten",
    "access control" : "Zugriffskontrolle",
    "create" : "erstellen",
    "change" : "Ändern",
    "delete" : "löschen",
    "Password protected" : "Passwortgeschützt",
    "Error unsetting expiration date" : "Fehler beim Entfernen des Ablaufdatums",
    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
    "Sending ..." : "Senden…",
    "Email sent" : "E-Mail gesendet",
    "Warning" : "Warnung",
    "This share is password-protected" : "Freigabe ist passwortgeschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Sort by name" : "Nach Name ordnen",
    "Sort by date" : "Nach Datum ordnen",
    "Cancel upload" : "Hochladen abbrechen",
    "Album information" : "Albuminformation",
    "File list" : "Dateiliste",
    "Sorry, this file could not be found." : "Diese Datei wurde leider nicht gefunden.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the wrong file ID was provided" : "Falsche Datei-ID wurde angegeben",
    "the file was removed" : "Die Datei wurde entfernt",
    "the file is corrupt" : "Die Datei ist beschädigt",
    "the encryption key is missing" : "Der Verschlüsselungsschlüssel fehlt",
    "Here is the error message returned by the server: " : "Diese Fehlermeldung wurde vom Server zurückgegeben:",
    "For more information, please contact your friendly Nextcloud administrator." : "Für weitere Informationen kontaktieren Sie bitte Ihren freundlichen Nextcloud-Administrator.",
    "Sorry, but the server could not fulfill your request." : "Der Server kann Ihre Anfrage leider nicht ausführen.",
    "Possible reasons for the problem:" : "Mögliche Gründe für das Problem:",
    "a conflicting app was installed" : "Eine konfliktträchtige App wurde installiert",
    "a required component is missing or was disconnected" : "Eine erforderliche Komponente fehlt oder wurde getrennt",
    "the filesystem is not readable" : "Das Dateisystem ist nicht lesbar",
    "Sorry, this link doesn't seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "the item was removed" : "Das Element wurde entfernt",
    "the link has expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more information, please ask the person who has sent you this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "Add to your Nextcloud" : "Zu Ihrer Nextcloud hinzufügen",
    "Picture view" : "Bildansicht",
    "Gallery view" : "Galerieansicht"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/de_DE.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "There was a problem reading files from this album" : "Es gab ein Problem Dateien aus diesem Album zu lesen",
    "Aborting preview. Could not find the file" : "Die Vorschau wird abgebrochen. Die Datei konnte nicht gefunden werden",
    "Could not move \"{file}\", target exists" : "Konnte \"{file}\" nicht verschieben, Ziel existiert bereits",
    "Could not move \"{file}\"" : "Konnte \"{file}\" nicht verschieben ",
    "No compatible server found at {remote}" : "Keinen kompatiblen Server unter {remote} gefunden",
    "Invalid server url" : "Ungültige Server-URL",
    "Could not load the description" : "Die Beschreibung konnte nicht geladen werden",
    "Could not load the description: " : "Die Beschreibung konnte nicht geladen werden:",
    "Copyright" : "Urheberrecht",
    "Could not load the copyright notice: " : "Der Urheberrechtshinweis konnte nicht geladen werden:",
    "Copyright notice" : "Urheberrechtshinweis",
    "Link to copyright document" : "Link zum Urheberrechts-Dokument",
    "This application may not work properly on your browser." : "Diese Anwendung könnte mit Ihrem Browser nicht einwandfrei funktionieren",
    "For an improved experience, please install one of the following alternatives" : "Für eine bessere Erfahrung installieren Sie bitte eine der folgenden Alternativen",
    "Your browser is not supported!" : "Ihr Browser wird nicht unterstützt!",
    "please install one of the following alternatives" : "Bitte eine der folgenden Alternativen installieren",
    "Album cannot be shown" : "Album kann nicht angezeigt werden.",
    "No media files found" : "Keine Mediendateien gefunden.",
    "Upload pictures in the Files app to display them here" : "Laden Sie Bilder in der Dateien-App hoch, damit diese hier angezeigt werden. ",
    "Upload new files via drag and drop or by using the [+] button above" : "Lade neue Dateien via Drag and Drop oder mit der [+]-Schaltfläche hoch.",
    "Configuration error" : "Konfigurationsfehler",
    "New" : "Neu",
    "Hide Album" : "Album ausblenden",
    "Could not hide album" : "Album konnte nicht ausgeblendet werden",
    "Error loading slideshow template" : "Fehler beim Laden der Slideshow-Vorlage",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fehler!</strong> Konnte keine Vorschau dieser Datei erzeugen.<br> Bitte wechseln Sie zum nächsten Bild, während im Hintergrund das Bild aus der Diashow entfernt wird.",
    "Next" : "Weiter",
    "Play" : "Abspielen",
    "Pause" : "Anhalten",
    "Previous" : "Zurück",
    "Close" : "Schließen",
    "Download" : "Herunterladen",
    "Toggle background" : "Hintergrund umschalten",
    "Delete" : "Löschen",
    "Share" : "Teilen",
    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}“ ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"{name}\" is not an allowed filetype" : "\"{name}“ ist kein erlaubter Dateityp ",
    "Upload" : "Hochladen",
    "Error" : "Fehler",
    "Error while sharing" : "Fehler beim Teilen",
    "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
    "Error while changing permissions" : "Fehler beim Ändern der Rechte",
    "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Ihnen und der Gruppe {group} geteilt.",
    "Shared with you by {owner}" : "{owner} hat dies mit Ihnen geteilt",
    "Share with users or groups …" : "Mit Benutzern oder Gruppen teilen…",
    "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder externen Benutzern teilen…",
    "Share link" : "Link teilen",
    "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
    "Link" : "Link",
    "Password protect" : "Passwortschutz",
    "Password" : "Passwort",
    "Choose a password for the public link" : "Passwort für den öffentlichen Link eingeben",
    "Allow editing" : "Bearbeitung erlauben",
    "Email link to person" : "Link per E-Mail versenden",
    "Send" : "Senden",
    "Set expiration date" : "Ein Ablaufdatum setzen",
    "Expiration" : "Ablaufdatum",
    "Expiration date" : "Ablaufdatum",
    "This list is maybe truncated - please refine your search term to see more results." : "Die Liste ist unter Umständen gekürzt - Bitte verfeinern Sie Ihre Suche um mehr Ergebnisse zu erhalten. ",
    "No users or groups found for {search}" : "Keine Benutzer oder Gruppen gefunden für {search}",
    "No users found for {search}" : "Keine Benutzer für {search} gefunden",
    "An error occurred (\"{message}\"). Please try again" : "Es ist ein Fehler aufgetreten (\"{message}\"). Bitte erneut versuchen.",
    "An error occurred. Please try again" : "Es ist ein Fehler aufgetreten. Bitte erneut versuchen.",
    "Adding user..." : "Benutzer wird hinzugefügt…",
    "group" : "Gruppe",
    "remote" : "Externe Freigabe",
    "Resharing is not allowed" : "Weiterteilen ist nicht erlaubt",
    "Error while retrieving shares" : "Fehler beim Abrufen der Freigaben",
    "Unshare" : "Freigabe aufheben",
    "notify by email" : "Per E-Mail benachrichtigen",
    "can share" : "kann teilen",
    "can edit" : "kann bearbeiten",
    "access control" : "Zugriffskontrolle",
    "create" : "erstellen",
    "change" : "Ändern",
    "delete" : "löschen",
    "Password protected" : "Passwortgeschützt",
    "Error unsetting expiration date" : "Fehler beim Entfernen des Ablaufdatums",
    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
    "Sending…" : "Sende…",
    "Email sent" : "E-Mail gesendet",
    "Warning" : "Warnung",
    "shared by %s" : "von %s geteilt",
    "Direct link" : "Direkter Link",
    "Add to your Nextcloud" : "Zu Ihrer Nextcloud hinzufügen",
    "This share is password-protected" : "Freigabe ist passwortgeschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Sort by name" : "Nach Name ordnen",
    "Sort by date" : "Nach Datum ordnen",
    "Cancel upload" : "Hochladen abbrechen",
    "Album information" : "Albuminformation",
    "File list" : "Dateiliste",
    "Sorry, this file could not be found." : "Diese Datei wurde leider nicht gefunden.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the wrong file ID was provided" : "Falsche Datei-ID wurde angegeben",
    "the file was removed" : "Die Datei wurde entfernt",
    "the file is corrupt" : "Die Datei ist beschädigt",
    "the encryption key is missing" : "Der Verschlüsselungsschlüssel fehlt",
    "Here is the error message returned by the server: " : "Diese Fehlermeldung wurde vom Server zurückgegeben:",
    "For more information, please contact your friendly Nextcloud administrator." : "Für weitere Informationen kontaktieren Sie bitte Ihren freundlichen Nextcloud-Administrator.",
    "Sorry, but the server could not fulfill your request." : "Der Server kann Ihre Anfrage leider nicht ausführen.",
    "Possible reasons for the problem:" : "Mögliche Gründe für das Problem:",
    "a conflicting app was installed" : "Eine konfliktträchtige App wurde installiert",
    "a required component is missing or was disconnected" : "Eine erforderliche Komponente fehlt oder wurde getrennt",
    "the filesystem is not readable" : "Das Dateisystem ist nicht lesbar",
    "Sorry, this link doesn't seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "the item was removed" : "Das Element wurde entfernt",
    "the link has expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more information, please ask the person who has sent you this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "Picture view" : "Bildansicht",
    "Gallery view" : "Galerieansicht",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Teile mit Menschen auf anderen Servern unter Verwendung ihrer Federated Cloud ID username@example.com/cloud",
    "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuchen Sie es noch einmal",
    "Sending ..." : "Senden…"
},
"nplurals=2; plural=(n != 1);");
